package com.abi.qms.platform.service.impl;

import com.abi.qms.platform.dao.mapper.ReportServiceMapper;
import com.abi.qms.platform.dao.vo.result.ListBrandCodeReportVO;
import com.abi.qms.platform.dao.vo.result.ListSkuCodeReportVO;
import com.abi.qms.platform.dto.req.ReportReq;
import com.abi.qms.platform.dto.res.ListBrandCodeReportRes;
import com.abi.qms.platform.dto.res.ListSkuCodeRankingReportRes;
import com.abi.qms.platform.service.ReportService;
import com.abi.task.common.utils.PojoConverterUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.text.DecimalFormat;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author ludashi
 * @date 2021年06月02日 15:39
 */
@Service
public class ReportServiceImpl implements ReportService {

    @Autowired
    private ReportServiceMapper reportServiceMapper;

   /**
    * 品牌使用码量占比
    * @author ludashi
    * @date 2021/6/2 17:50
    * @param reportReq
    * @return com.abi.qms.platform.dto.res.ListBrandCodeReportRes
    */
    @Override
    public ListBrandCodeReportRes queryBrandCodeProportion(ReportReq reportReq) {
        //查询 品牌数量
        List<ListBrandCodeReportVO> listReportVOS = reportServiceMapper.queryBrandCodeProportion(reportReq);
        //求总和
        Long collect = listReportVOS.stream().collect(Collectors.summingLong(ListBrandCodeReportVO::getQrNumber));
        if(!CollectionUtils.isEmpty(listReportVOS)){
            listReportVOS.forEach(listReportVO->{
                long l = listReportVO.getQrNumber() / collect * 100;
                listReportVO.setPercent(new DecimalFormat("#0.00").format(l + 0.000001d)+"%");
            });
        }
        // 封装出参
        ListBrandCodeReportRes res = new ListBrandCodeReportRes();
        List<ListBrandCodeReportRes.BrandCodeReportBean> reportRes = PojoConverterUtils.copyList(listReportVOS, ListBrandCodeReportRes.BrandCodeReportBean.class);
        res.setReportBrandCodeResList(reportRes);
        return res;
    }

    /**
     * SKU使用码量排名
     * @param reportReq
     * @return
     */
    @Override
    public ListSkuCodeRankingReportRes querySkuCodeRanking(ReportReq reportReq) {
        List<ListSkuCodeReportVO> listSkuCodeReportVOS = reportServiceMapper.querySkuCodeRanking(reportReq);
        // 封装出参
        ListSkuCodeRankingReportRes res = new ListSkuCodeRankingReportRes();
        List<ListSkuCodeRankingReportRes.SkuCodeReportResBean> skuCodeReportResBeans = PojoConverterUtils.copyList(listSkuCodeReportVOS, ListSkuCodeRankingReportRes.SkuCodeReportResBean.class);
        res.setReportSkuCodeRankingResList(skuCodeReportResBeans);
        return res;
    }
}
